@@ -10,7 +10,7 @@
 #include "editor/noteeditorutils.h"
 #include "notes/knote.h"
 
-#include <KPIMTextEdit/EditorUtil>
+#include <TextUtils/ConvertText>
 
 #include <PimCommon/KActionMenuChangeCase>
 
@@ -199,29 +199,25 @@ void KNoteEdit::setNote(KNote *_note)
 void KNoteEdit::slotReverseCase()
 {
     QTextCursor cursor = textCursor();
-    KPIMTextEdit::EditorUtil editorUtil;
-    editorUtil.reverseCase(cursor);
+    TextUtils::ConvertText::reverseCase(cursor);
 }
 
 void KNoteEdit::slotSentenceCase()
 {
     QTextCursor cursor = textCursor();
-    KPIMTextEdit::EditorUtil editorUtil;
-    editorUtil.sentenceCase(cursor);
+    TextUtils::ConvertText::sentenceCase(cursor);
 }
 
 void KNoteEdit::slotUpperCase()
 {
     QTextCursor cursor = textCursor();
-    KPIMTextEdit::EditorUtil editorUtil;
-    editorUtil.upperCase(cursor);
+    TextUtils::ConvertText::upperCase(cursor);
 }
 
 void KNoteEdit::slotLowerCase()
 {
     QTextCursor cursor = textCursor();
-    KPIMTextEdit::EditorUtil editorUtil;
-    editorUtil.lowerCase(cursor);
+    TextUtils::ConvertText::lowerCase(cursor);
 }
 
 QMenu *KNoteEdit::mousePopupMenu()
@@ -536,12 +532,8 @@ void KNoteEdit::slotCurrentCharFormatChanged(const QTextCharFormat &f)
     }
 
     // font changes
-#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     const QStringList families = f.fontFamilies().toStringList();
     const auto fontFamily = families.isEmpty() ? QString() : families.constFirst();
-#else
-    const auto fontFamily = f.fontFamily();
-#endif
     m_textFont->setFont(fontFamily);
     m_textSize->setFontSize((f.fontPointSize() > 0) ? (int)f.fontPointSize() : 10);
 
@@ -671,3 +663,5 @@ int KNoteEdit::cursorPositionFromStart() const
 {
     return textCursor().position();
 }
+
+#include "moc_knoteedit.cpp"
