@@ -8,8 +8,6 @@
 
 #include "knotebutton.h"
 
-#include <KIconLoader>
-
 #include <QPainter>
 #include <QStyleOption>
 
@@ -22,15 +20,13 @@ KNoteButton::KNoteButton(const QString &icon, QWidget *parent)
     setFlat(true);
 
     if (!icon.isEmpty()) {
-        setIcon(KIconLoader::global()->loadIcon(icon, KIconLoader::Small, 10));
+        setIcon(QIcon::fromTheme(icon));
     }
 }
 
-KNoteButton::~KNoteButton()
-{
-}
+KNoteButton::~KNoteButton() = default;
 
-void KNoteButton::enterEvent(QEvent *)
+void KNoteButton::enterEvent(QEnterEvent *)
 {
     setFlat(false);
     repaint();
@@ -49,7 +45,7 @@ int KNoteButton::heightForWidth(int w) const
 
 QSize KNoteButton::sizeHint() const
 {
-    return QSize(QPushButton::sizeHint().height(), QPushButton::sizeHint().height());
+    return {QPushButton::sizeHint().height(), QPushButton::sizeHint().height()};
 }
 
 void KNoteButton::paintEvent(QPaintEvent *)
@@ -107,3 +103,5 @@ void KNoteButton::paintEvent(QPaintEvent *)
         p.drawPixmap(dx, dy, pix);
     }
 }
+
+#include "moc_knotebutton.cpp"
